﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.HttpsPolicy;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.EntityFrameworkCore;
using Turkceleme.Models;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json.Serialization;

namespace Turkceleme
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            services.Configure<CookiePolicyOptions>(options =>
            {
                // This lambda determines whether user consent for non-essential cookies is needed for a given request.
                options.CheckConsentNeeded = context => true;
                options.MinimumSameSitePolicy = SameSiteMode.None;
            });

            services.AddMvc().AddJsonOptions(x => {
                x.SerializerSettings.ContractResolver = new DefaultContractResolver();
            });


            services.AddMvc()
                .SetCompatibilityVersion(CompatibilityVersion.Version_2_1)
                .AddJsonOptions(x => {
                    x.SerializerSettings.ContractResolver = new DefaultContractResolver();
                });
            services.AddAntiforgery(o => o.HeaderName = "XSRF-TOKEN");

            services.AddDbContext<TurkceContext>(options =>
                    options.UseSqlServer(Configuration.GetConnectionString("TurkceContext")));
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IHostingEnvironment env, ILoggerFactory loggerFactory)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }
            else
            {
                app.UseExceptionHandler("/Error");
                app.UseHsts();
            }

            Syncfusion.Licensing.SyncfusionLicenseProvider.RegisterLicense("Mzk1OTZAMzEzNjJlMzMyZTMwY3hva2hueE9Gb0hNNXRYRWFqc0RvcVRPR3FMQzNTUEU3SXR1TE9kM1MzYz0=");
            Syncfusion.Licensing.SyncfusionLicenseProvider.RegisterLicense("Mzk1OTZAMzEzNjJlMzMyZTMwY3hva2hueE9Gb0hNNXRYRWFqc0RvcVRPR3FMQzNTUEU3SXR1TE9kM1MzYz0=");

            loggerFactory.AddConsole(Configuration.GetSection("Logging"));
            loggerFactory.AddDebug();

            app.UseHttpsRedirection();
            app.UseStaticFiles();
            app.UseCookiePolicy();

            app.UseMvc();
        }
    }
}
